@@ -83,7 +83,16 @@ class WordPress(
         :param vpc: The WordPress VPC.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(WordPress.__init__)
+            def stub(
+                scope: aws_cdk.core.Construct,
+                id: builtins.str,
+                *,
+                cluster: typing.Optional[aws_cdk.aws_ecs.Cluster] = None,
+                rds_instance: typing.Optional[aws_cdk.aws_rds.DatabaseInstance] = None,
+                vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = WordPressProps(cluster=cluster, rds_instance=rds_instance, vpc=vpc)
@@ -116,7 +125,14 @@ class WordPressProps:
         :param vpc: The WordPress VPC.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(WordPressProps.__init__)
+            def stub(
+                *,
+                cluster: typing.Optional[aws_cdk.aws_ecs.Cluster] = None,
+                rds_instance: typing.Optional[aws_cdk.aws_rds.DatabaseInstance] = None,
+                vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument cluster", value=cluster, expected_type=type_hints["cluster"])
             check_type(argname="argument rds_instance", value=rds_instance, expected_type=type_hints["rds_instance"])
             check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
